
## CATO-CLI - mutation.policy.wanNetwork.removeSection:
[Click here](https://api.catonetworks.com/documentation/#mutation-removeSection) for documentation on this operation.

### Usage for mutation.policy.wanNetwork.removeSection:

`catocli mutation policy wanNetwork removeSection -h`

`catocli mutation policy wanNetwork removeSection <json>`

`catocli mutation policy wanNetwork removeSection "$(cat < removeSection.json)"`

`catocli mutation policy wanNetwork removeSection '{"policyRemoveSectionInput": {"id": {"id": "ID"}}, "wanNetworkPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}}'`

#### Operation Arguments for mutation.policy.wanNetwork.removeSection ####
`accountId` [ID] - (required) N/A 
`policyRemoveSectionInput` [PolicyRemoveSectionInput] - (required) N/A 
`wanNetworkPolicyMutationInput` [WanNetworkPolicyMutationInput] - (optional) N/A 
